/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 03050
 |            UNIFORM FACILITY DATA SET, 1998: [UNITED STATES]
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\03050-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE mode      -9='(-9) MISSING' 1='(1) Telephone' 2='(2) Mail survey' ;
  VALUE stfips    -9='(-9) MISSING' 1='(01) ALABAMA' 2='(02) ALASKA'
                  3='(03) ARKANSAS' 4='(04) ARIZONA' 5='(05) ARKANSAS'
                  6='(06) CALIFORNIA' 7='(07) CONNECTICUT' 8='(08) COLORADO'
                  9='(09) CONNECTICUT' 10='(10) DELAWARE'
                  11='(11) DIST OF COLUMBIA' 12='(12) FLORIDA'
                  13='(13) GEORGIA' 14='(14) IDAHO' 15='(15) HAWAII'
                  16='(16) IDAHO' 17='(17) ILLINOIS' 18='(18) INDIANA'
                  19='(19) IOWA' 20='(20) KANSAS' 21='(21) KENTUCKY'
                  22='(22) LOUISIANA' 23='(23) MAINE' 24='(24) MARYLAND'
                  25='(25) MASSACHUSETTS' 26='(26) MICHIGAN'
                  27='(27) MINNESOTA' 28='(28) MISSISSIPPI'
                  29='(29) MISSOURI' 30='(30) MONTANA' 31='(31) NEBRASKA'
                  32='(32) NEVADA' 33='(33) NEW HAMPSHIRE'
                  34='(34) NEW JERSEY' 35='(35) NEW MEXICO'
                  36='(36) NEW YORK' 37='(37) NORTH CAROLINA'
                  38='(38) NORTH DAKOTA' 39='(39) OHIO' 40='(40) OKLAHOMA'
                  41='(41) OREGON' 42='(42) PENNSYLVANIA'
                  43='(43) SOUTH DAKOTA' 44='(44) RHODE ISLAND'
                  45='(45) SOUTH CAROLINA' 46='(46) SOUTH DAKOTA'
                  47='(47) TENNESSEE' 48='(48) TEXAS' 49='(49) UTAH'
                  50='(50) VERMONT' 51='(51) VIRGINIA' 52='(52) WYOMING'
                  53='(53) WASHINGTON' 54='(54) WEST VIRGINIA'
                  55='(55) WISCONSIN' 56='(56) WYOMING'
                  57='(57) VIRGIN ISLANDS' 60='(60) AMERICAN SAMOA'
                  64='(64) FED MICRONESIA' 66='(66) GUAM' 70='(70) PALAU'
                  72='(72) PUERTO RICO' 78='(78) VIRGIN ISLANDS' ;
  VALUE treatmt   -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE detox     -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE prevntn   -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE othnontx  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE ownershp  -9='(-9) MISSING' 1='(1) A private-for-profit organization'
                  2='(2) A private non-profit organization'
                  3='(3) State government'
                  4='(4) Local, county or community government'
                  5='(5) Tribal government' 6='(6) Federal government' ;
  VALUE fedown    -9='(-9) MISSING' 1='(1) Department of Veterans Affairs'
                  2='(2) Department of Defense' 3='(3) Bureau of prisons'
                  4='(4) Indian Health Service' 5='(5) Other' ;
  VALUE loc1ffff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc2ffff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc3ffff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc4ffff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc5ffff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc6ffff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc7ffff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc8ffff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc9ffff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc10fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc11fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc12fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc13fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc14fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc15fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE loc16fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE mgmcare   -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE writarra  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No'
                  3='(3) Don''t know' ;
  VALUE writnum   -9='(-9) MISSING' ;
  VALUE owner     -9='(-9) MISSING' 1='(1) Private non-profit'
                  2='(2) Private for profit'
                  3='(3) Local, community government'
                  4='(4) State Government' 5='(5) Federal Government'
                  6='(6) Tribal Government' ;
  VALUE setting   -9='(-9) MISSING' 1='(01) Outpatient' 2='(02) Residential'
                  3='(03) Outpatient and residential'
                  4='(04) Community Mental Health Center'
                  5='(05) Solo / Group practice' 6='(06) General Hospital'
                  7='(07) Psych Hospital' 8='(08) Criminal Justice'
                  9='(09) Community and religious' 10='(10) Health Center'
                  11='(11) Mixed / Other' ;
  VALUE admin     -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc1fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc2fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc3fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc4fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc5fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc6fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc7fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc8fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc9fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc10ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc11ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc12ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc13ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc14ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc15ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc16ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc17ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc18ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc19ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc20ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc21ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc22ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc23ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc24ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc25ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc26ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc27ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc28ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc29ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc36ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc37ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc38ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc39ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc40ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc41ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc42ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc43ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc44ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc45ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc46ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc47ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc48ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc49ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc50ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc51ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc52ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc53ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc54ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc55ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc56ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc57ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc58ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc59ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc60ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc30ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc31ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc32ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc33ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc34ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE srvc35ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE type1fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE type2fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE type3fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE type4fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE type5fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE type6fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE type7fff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE adminlnk  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE facnum    -9='(-9) MISSING' ;
  VALUE othfac1f  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE othfac2f  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE othfac3f  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE clientsf  -9='(-9) MISSING' ;
  VALUE hisvc     -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE hospbed   -9='(-9) MISSING' ;
  VALUE t_cli1ff  -9='(-9) MISSING' ;
  VALUE t_cli2ff  -9='(-9) MISSING' ;
  VALUE t_clihi   -9='(-9) MISSING' ;
  VALUE himetlam  -9='(-9) MISSING' 1='(1) Does not dispense'
                  2='(2) Does dispense' ;
  VALUE himetnum  -9='(-9) MISSING' ;
  VALUE hilamnum  -9='(-9) MISSING' ;
  VALUE h_sex1ff  -9='(-9) MISSING' ;
  VALUE h_sex2ff  -9='(-9) MISSING' ;
  VALUE h_sex3ff  -9='(-9) MISSING' ;
  VALUE h_sex4ff  -9='(-9) MISSING' ;
  VALUE h_re1fff  -9='(-9) MISSING' ;
  VALUE h_re2fff  -9='(-9) MISSING' ;
  VALUE h_re3fff  -9='(-9) MISSING' ;
  VALUE h_re4fff  -9='(-9) MISSING' ;
  VALUE h_re5fff  -9='(-9) MISSING' ;
  VALUE h_re6fff  -9='(-9) MISSING' ;
  VALUE h_re7fff  -9='(-9) MISSING' ;
  VALUE h_re8fff  -9='(-9) MISSING' ;
  VALUE h_age1ff  -9='(-9) MISSING' ;
  VALUE h_age2ff  -9='(-9) MISSING' ;
  VALUE h_age3ff  -9='(-9) MISSING' ;
  VALUE h_age4ff  -9='(-9) MISSING' ;
  VALUE h_age5ff  -9='(-9) MISSING' ;
  VALUE h_age6ff  -9='(-9) MISSING' ;
  VALUE h_age7ff  -9='(-9) MISSING' ;
  VALUE h_age8ff  -9='(-9) MISSING' ;
  VALUE h_age9ff  -9='(-9) MISSING' ;
  VALUE rcsvc     -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE resbed    -9='(-9) MISSING' ;
  VALUE t_cli3ff  -9='(-9) MISSING' ;
  VALUE t_cli4ff  -9='(-9) MISSING' ;
  VALUE t_clirc   -9='(-9) MISSING' ;
  VALUE rcmetlam  -9='(-9) MISSING' 1='(1) Does not dispense'
                  2='(2) Does dispense' ;
  VALUE rcmetnum  -9='(-9) MISSING' ;
  VALUE rclamnum  -9='(-9) MISSING' ;
  VALUE r_sex1ff  -9='(-9) MISSING' ;
  VALUE r_sex2ff  -9='(-9) MISSING' ;
  VALUE r_sex3ff  -9='(-9) MISSING' ;
  VALUE r_sex4ff  -9='(-9) MISSING' ;
  VALUE r_re1fff  -9='(-9) MISSING' ;
  VALUE r_re2fff  -9='(-9) MISSING' ;
  VALUE r_re3fff  -9='(-9) MISSING' ;
  VALUE r_re4fff  -9='(-9) MISSING' ;
  VALUE r_re5fff  -9='(-9) MISSING' ;
  VALUE r_re6fff  -9='(-9) MISSING' ;
  VALUE r_re7fff  -9='(-9) MISSING' ;
  VALUE r_re8fff  -9='(-9) MISSING' ;
  VALUE r_age1ff  -9='(-9) MISSING' ;
  VALUE r_age2ff  -9='(-9) MISSING' ;
  VALUE r_age3ff  -9='(-9) MISSING' ;
  VALUE r_age4ff  -9='(-9) MISSING' ;
  VALUE r_age5ff  -9='(-9) MISSING' ;
  VALUE r_age6ff  -9='(-9) MISSING' ;
  VALUE r_age7ff  -9='(-9) MISSING' ;
  VALUE r_age8ff  -9='(-9) MISSING' ;
  VALUE r_age9ff  -9='(-9) MISSING' ;
  VALUE outsvc    -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE t_cli7ff  -9='(-9) MISSING' ;
  VALUE t_cli6ff  -9='(-9) MISSING' ;
  VALUE t_cli5ff  -9='(-9) MISSING' ;
  VALUE t_cliop   -9='(-9) MISSING' ;
  VALUE opmetlam  -9='(-9) MISSING' 1='(1) Does not dispense'
                  2='(2) Does dispense' ;
  VALUE opmetnum  -9='(-9) MISSING' ;
  VALUE oplamnum  -9='(-9) MISSING' ;
  VALUE o_sex1ff  -9='(-9) MISSING' ;
  VALUE o_sex2ff  -9='(-9) MISSING' ;
  VALUE o_sex3ff  -9='(-9) MISSING' ;
  VALUE o_sex4ff  -9='(-9) MISSING' ;
  VALUE o_re1fff  -9='(-9) MISSING' ;
  VALUE o_re2fff  -9='(-9) MISSING' ;
  VALUE o_re3fff  -9='(-9) MISSING' ;
  VALUE o_re4fff  -9='(-9) MISSING' ;
  VALUE o_re5fff  -9='(-9) MISSING' ;
  VALUE o_re6fff  -9='(-9) MISSING' ;
  VALUE o_re7fff  -9='(-9) MISSING' ;
  VALUE o_re8fff  -9='(-9) MISSING' ;
  VALUE o_age1ff  -9='(-9) MISSING' ;
  VALUE o_age2ff  -9='(-9) MISSING' ;
  VALUE o_age3ff  -9='(-9) MISSING' ;
  VALUE o_age4ff  -9='(-9) MISSING' ;
  VALUE o_age5ff  -9='(-9) MISSING' ;
  VALUE o_age6ff  -9='(-9) MISSING' ;
  VALUE o_age7ff  -9='(-9) MISSING' ;
  VALUE o_age8ff  -9='(-9) MISSING' ;
  VALUE o_age9ff  -9='(-9) MISSING' ;
  VALUE totadmis  -9='(-9) MISSING' ;
  VALUE sacl98ff  -9='(-9) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b_pct     -9='(-9) MISSING' ;
  VALUE a_pct     -9='(-9) MISSING' ;
  VALUE d_pct     -9='(-9) MISSING' ;
  VALUE injpct    -9='(-9) MISSING' ;
  VALUE tbpct     -9='(-9) MISSING' ;
  VALUE hivpct    -9='(-9) MISSING' ;
  VALUE prevpct   -9='(-9) MISSING' ;
  VALUE mgdpct    -9='(-9) MISSING' ;
  VALUE ctpct     -9='(-9) MISSING' ;
  VALUE pregpct   -9='(-9) MISSING' ;
  VALUE deppct    -9='(-9) MISSING' ;
  VALUE opmltotl  -9='(-9) MISSING' ;
  VALUE himltotl  -9='(-9) MISSING' ;
  VALUE rcmltotl  -9='(-9) MISSING' ;
  VALUE male      -9='(-9) MISSING' ;
  VALUE female    -9='(-9) MISSING' ;
  VALUE unknown   -9='(-9) MISSING' ;
  VALUE ttlgndr   -9='(-9) MISSING' ;
  VALUE white     -9='(-9) MISSING' ;
  VALUE black     -9='(-9) MISSING' ;
  VALUE hispanic  -9='(-9) MISSING' ;
  VALUE asian     -9='(-9) MISSING' ;
  VALUE amerindn  -9='(-9) MISSING' ;
  VALUE other     -9='(-9) MISSING' ;
  VALUE unkrace   -9='(-9) MISSING' ;
  VALUE ttlrace   -9='(-9) MISSING' ;
  VALUE under18f  -9='(-9) MISSING' ;
  VALUE x18_20ff  -9='(-9) MISSING' ;
  VALUE x21_24ff  -9='(-9) MISSING' ;
  VALUE x25_34ff  -9='(-9) MISSING' ;
  VALUE x35_44ff  -9='(-9) MISSING' ;
  VALUE x45_64ff  -9='(-9) MISSING' ;
  VALUE over65ff  -9='(-9) MISSING' ;
  VALUE unkage    -9='(-9) MISSING' ;
  VALUE ttlage    -9='(-9) MISSING' ;
  VALUE h_sex1fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_sex2fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_sex3fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_sex4fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_re1fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_re2fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_re3fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_re4fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_re5fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_re6fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_re7fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_re8fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_age1fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_age2fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_age3fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_age4fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_age5fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_age6fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_age7fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_age8fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE h_age9fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_sex1fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_sex2fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_sex3fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_sex4fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_re1fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_re2fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_re3fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_re4fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_re5fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_re6fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_re7fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_re8fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_age1fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_age2fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_age3fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_age4fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_age5fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_age6fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_age7fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_age8fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE o_age9fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_sex1fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_sex2fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_sex3fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_sex4fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_re1fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_re2fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_re3fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_re4fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_re5fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_re6fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_re7fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_re8fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_age1fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_age2fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_age3fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_age4fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_age5fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_age6fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_age7fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_age8fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE r_age9fl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE tcli1fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE tcli2fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE tcli3fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE tcli4fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE tcli5fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE tcli6fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE tcli7fl   -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE tclircfl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE tcliopfl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
  VALUE tclihifl  -9='(-9) MISSING' 0='(0) Value not imputed'
                  1='(1) Value Imputed'
                  2='(2) Value not imputed/not used in imputation' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=732;
INPUT
        CASEID 1-5              MODE 6-7                STFIPS 8-9
        TREATMT 10-11           DETOX 12-13             PREVNTN 14-15
        OTHNONTX 16-17          OWNERSHP 18-19          FEDOWN 20-21
        LOC1 22-23              LOC2 24-25              LOC3 26-27
        LOC4 28-29              LOC5 30-31              LOC6 32-33
        LOC7 34-35              LOC8 36-37              LOC9 38-39
        LOC10 40-41             LOC11 42-43             LOC12 44-45
        LOC13 46-47             LOC14 48-49             LOC15 50-51
        LOC16 52-53             MGMCARE 54-55           WRITARRA 56-57
        WRITNUM 58-60           OWNER 61-62             SETTING 63-64
        ADMIN 65-66             SRVC1 67-68             SRVC2 69-70
        SRVC3 71-72             SRVC4 73-74             SRVC5 75-76
        SRVC6 77-78             SRVC7 79-80             SRVC8 81-82
        SRVC9 83-84             SRVC10 85-86            SRVC11 87-88
        SRVC12 89-90            SRVC13 91-92            SRVC14 93-94
        SRVC15 95-96            SRVC16 97-98            SRVC17 99-100
        SRVC18 101-102          SRVC19 103-104          SRVC20 105-106
        SRVC21 107-108          SRVC22 109-110          SRVC23 111-112
        SRVC24 113-114          SRVC25 115-116          SRVC26 117-118
        SRVC27 119-120          SRVC28 121-122          SRVC29 123-124
        SRVC36 125-126          SRVC37 127-128          SRVC38 129-130
        SRVC39 131-132          SRVC40 133-134          SRVC41 135-136
        SRVC42 137-138          SRVC43 139-140          SRVC44 141-142
        SRVC45 143-144          SRVC46 145-146          SRVC47 147-148
        SRVC48 149-150          SRVC49 151-152          SRVC50 153-154
        SRVC51 155-156          SRVC52 157-158          SRVC53 159-160
        SRVC54 161-162          SRVC55 163-164          SRVC56 165-166
        SRVC57 167-168          SRVC58 169-170          SRVC59 171-172
        SRVC60 173-174          SRVC30 175-176          SRVC31 177-178
        SRVC32 179-180          SRVC33 181-182          SRVC34 183-184
        SRVC35 185-186          TYPE1 187-188           TYPE2 189-190
        TYPE3 191-192           TYPE4 193-194           TYPE5 195-196
        TYPE6 197-198           TYPE7 199-200           ADMINLNK 201-202
        FACNUM 203-204          OTHFAC1 205-206         OTHFAC2 207-208
        OTHFAC3 209-210         CLIENTS4 211-214        HISVC 215-216
        HOSPBED 217-219         T_CLI1 220-222          T_CLI2 223-225
        T_CLIHI 226-228         HIMETLAM 229-230        HIMETNUM 231-233
        HILAMNUM 234-235        H_SEX1 236-238          H_SEX2 239-241
        H_SEX3 242-243          H_SEX4 244-246          H_RE1 247-249
        H_RE2 250-252           H_RE3 253-254           H_RE4 255-256
        H_RE5 257-258           H_RE6 259-260           H_RE7 261-262
        H_RE8 263-265           H_AGE1 266-268          H_AGE2 269-270
        H_AGE3 271-272          H_AGE4 273-274          H_AGE5 275-277
        H_AGE6 278-280          H_AGE7 281-282          H_AGE8 283-284
        H_AGE9 285-287          RCSVC 288-289           RESBED 290-293
        T_CLI3 294-296          T_CLI4 297-300          T_CLIRC 301-304
        RCMETLAM 305-306        RCMETNUM 307-308        RCLAMNUM 309-310
        R_SEX1 311-314          R_SEX2 315-317          R_SEX3 318-319
        R_SEX4 320-323          R_RE1 324-326           R_RE2 327-329
        R_RE3 330-332           R_RE4 333-334           R_RE5 335-337
        R_RE6 338-339           R_RE7 340-341           R_RE8 342-345
        R_AGE1 346-348          R_AGE2 349-351          R_AGE3 352-354
        R_AGE4 355-357          R_AGE5 358-360          R_AGE6 361-363
        R_AGE7 364-365          R_AGE8 366-367          R_AGE9 368-371
        OUTSVC 372-373          T_CLI7 374-376          T_CLI6 377-380
        T_CLI5 381-384          T_CLIOP 385-388         OPMETLAM 389-390
        OPMETNUM 391-394        OPLAMNUM 395-397        O_SEX1 398-401
        O_SEX2 402-405          O_SEX3 406-407          O_SEX4 408-411
        O_RE1 412-415           O_RE2 416-419           O_RE3 420-423
        O_RE4 424-426           O_RE5 427-429           O_RE6 430-432
        O_RE7 433-434           O_RE8 435-438           O_AGE1 439-441
        O_AGE2 442-444          O_AGE3 445-447          O_AGE4 448-451
        O_AGE5 452-454          O_AGE6 455-458          O_AGE7 459-461
        O_AGE8 462-463          O_AGE9 464-467          TOTADMIS 468-472
        SACL98 473-474          B_PCT 475-477           A_PCT 478-480
        D_PCT 481-483           INJPCT 484-486          TBPCT 487-489
        HIVPCT 490-492          PREVPCT 493-495         MGDPCT 496-498
        CTPCT 499-501           PREGPCT 502-504         DEPPCT 505-507
        OPMLTOTL 508-511        HIMLTOTL 512-514        RCMLTOTL 515-516
        MALE 517-520            FEMALE 521-524          UNKNOWN 525-526
        TTLGNDR 527-530         WHITE 531-534           BLACK 535-538
        HISPANIC 539-542        ASIAN 543-545           AMERINDN 546-548
        OTHER 549-551           UNKRACE 552-553         TTLRACE 554-557
        UNDER18 558-560         X18_20 561-563          X21_24 564-566
        X25_34 567-570          X35_44 571-573          X45_64 574-577
        OVER65 578-580          UNKAGE 581-582          TTLAGE 583-586
        H_SEX1FL 587-588        H_SEX2FL 589-590        H_SEX3FL 591-592
        H_SEX4FL 593-594        H_RE1FL 595-596         H_RE2FL 597-598
        H_RE3FL 599-600         H_RE4FL 601-602         H_RE5FL 603-604
        H_RE6FL 605-606         H_RE7FL 607-608         H_RE8FL 609-610
        H_AGE1FL 611-612        H_AGE2FL 613-614        H_AGE3FL 615-616
        H_AGE4FL 617-618        H_AGE5FL 619-620        H_AGE6FL 621-622
        H_AGE7FL 623-624        H_AGE8FL 625-626        H_AGE9FL 627-628
        O_SEX1FL 629-630        O_SEX2FL 631-632        O_SEX3FL 633-634
        O_SEX4FL 635-636        O_RE1FL 637-638         O_RE2FL 639-640
        O_RE3FL 641-642         O_RE4FL 643-644         O_RE5FL 645-646
        O_RE6FL 647-648         O_RE7FL 649-650         O_RE8FL 651-652
        O_AGE1FL 653-654        O_AGE2FL 655-656        O_AGE3FL 657-658
        O_AGE4FL 659-660        O_AGE5FL 661-662        O_AGE6FL 663-664
        O_AGE7FL 665-666        O_AGE8FL 667-668        O_AGE9FL 669-670
        R_SEX1FL 671-672        R_SEX2FL 673-674        R_SEX3FL 675-676
        R_SEX4FL 677-678        R_RE1FL 679-680         R_RE2FL 681-682
        R_RE3FL 683-684         R_RE4FL 685-686         R_RE5FL 687-688
        R_RE6FL 689-690         R_RE7FL 691-692         R_RE8FL 693-694
        R_AGE1FL 695-696        R_AGE2FL 697-698        R_AGE3FL 699-700
        R_AGE4FL 701-702        R_AGE5FL 703-704        R_AGE6FL 705-706
        R_AGE7FL 707-708        R_AGE8FL 709-710        R_AGE9FL 711-712
        TCLI1FL 713-714         TCLI2FL 715-716         TCLI3FL 717-718
        TCLI4FL 719-720         TCLI5FL 721-722         TCLI6FL 723-724
        TCLI7FL 725-726         TCLIRCFL 727-728        TCLIOPFL 729-730
        TCLIHIFL 731-732        ;


* SAS LABEL STATEMENT;

LABEL 
   CASEID  = 'CASE IDENTIFICATION NUMBER' 
   MODE    = '1=Phone Complete 2=Mail Complete' 
   STFIPS  = 'STATE' 
   TREATMT = 'On 10/1/98-Provided Treatment Services' 
   DETOX   = 'On 10/1/98-Provided Detox Services' 
   PREVNTN = 'On 10/1/98-Provided Prevention Services' 
   OTHNONTX= 'On 10/1/98-Provided Other Services' 
   OWNERSHP= 'Ownership' 
   FEDOWN  = 'Federal Government Agency' 
   LOC1    = 'Setting, General Hospital' 
   LOC2    = 'Setting, Psychiatric Hospital' 
   LOC3    = 'Setting, Other Specialized Hospital' 
   LOC4    = 'Setting, Outpatient Facility' 
   LOC5    = 'Setting, Halfway House' 
   LOC6    = 'Setting, Residential Facility' 
   LOC7    = 'TC Included - Yes/No' 
   LOC8    = 'Setting, Mental Health Center' 
   LOC9    = 'Setting, Health Center' 
   LOC10   = 'Setting, School' 
   LOC11   = 'Setting, Religious Organization' 
   LOC12   = 'Setting, Jail or Prison' 
   LOC13   = 'Setting, Other Criminal Justice' 
   LOC14   = 'Setting, Private Group Practice' 
   LOC15   = 'Setting, Private Solo Practice' 
   LOC16   = 'Setting, Other Private Setting' 
   MGMCARE = 'Facility Owned by Mgd Care Organztion' 
   WRITARRA= 'Facility Have Contracts w/Mgd Care' 
   WRITNUM = 'How Many Mgd Care Contracts' 
   OWNER   = 'OWNERSHIP-VALUES REARRANGED FOR TABLES' 
   SETTING = 'SETTING-VALUES REARRANGED FOR TABLES' 
   ADMIN   = 'On 10/1/98-Provided Admin Services' 
   SRVC1   = 'Assessment Comprehensive Sub Abuse' 
   SRVC2   = 'Assessment Mental Health' 
   SRVC3   = 'Assessment Other' 
   SRVC4   = 'Therapy Family Counseling' 
   SRVC5   = 'Therapy Group' 
   SRVC6   = 'Therapy Individual' 
   SRVC7   = 'Therapy Pharmaco/Prescription Med' 
   SRVC8   = 'Therapy Relapse Prevention Groups' 
   SRVC9   = 'Therapy Other' 
   SRVC10  = 'Testing Blood/Alcohol' 
   SRVC11  = 'Testing Drug/Alcohol Urine Screen' 
   SRVC12  = 'Testing Hair Analysis' 
   SRVC13  = 'Testing Hepatitis' 
   SRVC14  = 'Testing HIV' 
   SRVC15  = 'Testing STD' 
   SRVC16  = 'Testing TB Screening' 
   SRVC17  = 'Testing Other' 
   SRVC18  = 'Health Services Family Planning' 
   SRVC19  = 'Health Services Medical Care' 
   SRVC20  = 'Health Services Prenatal Care' 
   SRVC21  = 'Health Services Perinatal Care' 
   SRVC22  = 'Health Services TB Treatment' 
   SRVC23  = 'Health Services Hlth Education' 
   SRVC24  = 'Health Services HIV/AIDS Education' 
   SRVC25  = 'Health Services Smoking Cessation' 
   SRVC26  = 'Health Services Other' 
   SRVC27  = 'Continuing Care Aftercare Counseling' 
   SRVC28  = 'Continuing Care Alumni(ae) Groups' 
   SRVC29  = 'Continuing Care Other' 
   SRVC36  = 'Transitional Assist. Social Services' 
   SRVC37  = 'Transitional Services Discharge Plan' 
   SRVC38  = 'Transitional Services Employment' 
   SRVC39  = 'Transitional Services Housing Assist' 
   SRVC40  = 'Transitional Services Referral' 
   SRVC41  = 'Transitional Services Other' 
   SRVC42  = 'Comm Outreach Drug/Alcohol Ed' 
   SRVC43  = 'Comm Outreach Early Intervention' 
   SRVC44  = 'Comm Outreach Medical Presentations' 
   SRVC45  = 'Comm Outreach Membership Prog' 
   SRVC46  = 'Comm Outreach Other' 
   SRVC47  = 'Other Services Academic Ed/GED' 
   SRVC48  = 'Other Services Acupuncture' 
   SRVC49  = 'Other Services Case Management' 
   SRVC50  = 'Other Services Child Care' 
   SRVC51  = 'Other Services Communication Skill' 
   SRVC52  = 'Other Services Domestic Violence' 
   SRVC53  = 'Other Services Home Visits' 
   SRVC54  = 'Other Services Life Skills' 
   SRVC55  = 'Other Services Outcome Follow-Up' 
   SRVC56  = 'Other Services Parenting/family' 
   SRVC57  = 'Other Services Self-help Grps' 
   SRVC58  = 'Other Services Socialization' 
   SRVC59  = 'Other Services Transportation' 
   SRVC60  = 'Other Services Other' 
   SRVC30  = 'Programs for Adolescents' 
   SRVC31  = 'Programs for Dual Diagnosis' 
   SRVC32  = 'Programs for HIV/AID' 
   SRVC33  = 'Programs for Pregnant or Postpartum' 
   SRVC34  = 'Other Services Womens Groups' 
   SRVC35  = 'Facility Provides Other Special Groups' 
   TYPE1   = 'Outpatient Detox' 
   TYPE2   = 'Intensive Outpatient Treatment' 
   TYPE3   = 'Other Outpatient Treatment' 
   TYPE4   = 'Hospital Inpatient Detox' 
   TYPE5   = 'Hospital Inpatient Rehabilitation' 
   TYPE6   = 'Non-hospital Residential Detox' 
   TYPE7   = 'Non-hospital Residential Rehab' 
   ADMINLNK= 'Facility Part of Network-Yes/No' 
   FACNUM  = '# of Facilities in Client Count Data' 
   OTHFAC1 = 'Client Counts-Fac Combined w/Others' 
   OTHFAC2 = 'Client Counts-This Facility Only' 
   OTHFAC3 = 'Cannot Provide Any Client Counts' 
   CLIENTS4= 'TOTAL OF T_CLI1-T_CLI7 AFTER EDITS' 
   HISVC   = 'Hospital Inpatient Treatment Offered' 
   HOSPBED = 'Total Beds Designated-Hospital Inpatient' 
   T_CLI1  = 'Hosp. Inpatient Clients,Detox' 
   T_CLI2  = 'Hosp. Inpatient Clients,Rehab' 
   T_CLIHI = 'Total Number of Hospital Inpatients' 
   HIMETLAM= 'Meth/LAAM Dispensed-Inpatients' 
   HIMETNUM= 'Total Methadone Inpatients' 
   HILAMNUM= 'Total LAAM Inpatients' 
   H_SEX1  = 'Hosp Inp Male Clients' 
   H_SEX2  = 'Hosp Inp Female Clients' 
   H_SEX3  = 'Hosp Inp Unknown Clients gender' 
   H_SEX4  = 'Hosp Inp Clients Gender total' 
   H_RE1   = 'Hosp Inp Clients/White' 
   H_RE2   = 'Hosp Inp Clients/Black' 
   H_RE3   = 'Hosp Inp Clients/Hispanic' 
   H_RE4   = 'Hosp Inp Clients Asian or Pacific' 
   H_RE5   = 'Hosp Inp Clients American Indian/A.N.' 
   H_RE6   = 'Hosp Inp Clients Of other race/ethnic' 
   H_RE7   = 'Hosp Inp Unknown Clients race/ethnic' 
   H_RE8   = 'Hosp Inp Clients Race/ethnic total' 
   H_AGE1  = 'Hosp Inp Clients Under 18 years old' 
   H_AGE2  = 'Hosp Inp Clients Between age 18 - 20' 
   H_AGE3  = 'Hosp Inp Clients Between age 21 - 24' 
   H_AGE4  = 'Hosp Inp Clients Age 25-34 years' 
   H_AGE5  = 'Hosp Inp Clients Age 35-44 years' 
   H_AGE6  = 'Hosp Inp Clients Age 45-64 years' 
   H_AGE7  = 'Hosp Inp Clients Age 65 and over' 
   H_AGE8  = 'Hosp Inp Clients Age unknown' 
   H_AGE9  = 'Hosp Inp Clients Age total' 
   RCSVC   = 'Residential (24hr) Treatment Offered' 
   RESBED  = 'Total Beds - Residential (24hr) Clients' 
   T_CLI3  = 'Residential (24hr) Clients,detox' 
   T_CLI4  = 'Residential (24hr) Clients,rehab' 
   T_CLIRC = 'Total (24hr) Residential Clients' 
   RCMETLAM= 'Meth/LAAM Dispensed-Residential' 
   RCMETNUM= 'Total Methadone Residential' 
   RCLAMNUM= 'Total LAAM Residential' 
   R_SEX1  = 'Residential Male Clients' 
   R_SEX2  = 'Residential Female Clients' 
   R_SEX3  = 'Residential Unknown Clients Gender' 
   R_SEX4  = 'Residential Clients Gender Total' 
   R_RE1   = 'Residential Clients/White' 
   R_RE2   = 'Residential Clients/Black' 
   R_RE3   = 'Residential Clients/Hispanic' 
   R_RE4   = 'Residential Clients Asian or Pacific' 
   R_RE5   = 'Residential Clients American Indian/A.N.' 
   R_RE6   = 'Residential Clients Of other race/ethnic' 
   R_RE7   = 'Residential Unknown Clients race/ethnic' 
   R_RE8   = 'Residential Clients Race/ethnic total' 
   R_AGE1  = 'Residential Clients Under 18 years old' 
   R_AGE2  = 'Residential Clients Between Age 18 - 20' 
   R_AGE3  = 'Residential Clients Between Age 21 - 24' 
   R_AGE4  = 'Residential Clients Age 25-34 Years' 
   R_AGE5  = 'Residential Clients Age 35-44 Years' 
   R_AGE6  = 'Residential Clients Age 45-64 Years' 
   R_AGE7  = 'Residential Clients Age 65 and Over' 
   R_AGE8  = 'Residential Clients Age Unknown' 
   R_AGE9  = 'Residential Clients Age Total' 
   OUTSVC  = 'Outpatient Treatment Offered-Yes/No' 
   T_CLI7  = 'Clients in Outpatient Detox' 
   T_CLI6  = 'Clients in Intensive outpatients' 
   T_CLI5  = 'Clients in Other Outpatient Care' 
   T_CLIOP = 'Total Number of Outpatient Clients' 
   OPMETLAM= 'Meth/LAAM Dispensed-Outpatients' 
   OPMETNUM= 'Total Methadone Outpatients' 
   OPLAMNUM= 'Total LAAM Outpatients' 
   O_SEX1  = 'Outpatient Male Clients' 
   O_SEX2  = 'Outpatient Female Clients' 
   O_SEX3  = 'Outpatient Clients Gender,Unknown' 
   O_SEX4  = 'Outpatient Clients Gender,Total' 
   O_RE1   = 'Outpatient Clients/white' 
   O_RE2   = 'Outpatient Clients/black' 
   O_RE3   = 'Outpatient Clients/hispanic' 
   O_RE4   = 'Outpatient Clients Asian or Pacific' 
   O_RE5   = 'Outpatient Clients American Indian/A.N.' 
   O_RE6   = 'Outpatient Clients of other race/ethnic' 
   O_RE7   = 'Outpatient Unknown clients race/ethnic' 
   O_RE8   = 'Outpatient Clients race/ethnic total' 
   O_AGE1  = 'Outpatient Clients under 18 years old' 
   O_AGE2  = 'Outpatient Clients between age 18 - 20' 
   O_AGE3  = 'Outpatient Clients between age 21 - 24' 
   O_AGE4  = 'Outpatient Clients age 25-34 years' 
   O_AGE5  = 'Outpatient Clients age 35-44 years' 
   O_AGE6  = 'Outpatient Clients age 45-64 years' 
   O_AGE7  = 'Outpatient Clients age 65 and over' 
   O_AGE8  = 'Outpatient Clients age unknown' 
   O_AGE9  = 'Outpatient Clients age total' 
   TOTADMIS= 'Total # of admissions for Sub Abuse tx' 
   SACL98  = 'Facility had no SA treatment on 10-1-98' 
   B_PCT   = '% of Clients Treated For Alc/Drug Abuse' 
   A_PCT   = '% of Clients Treated For Alc Abuse' 
   D_PCT   = '% of Clients Treated For Drug Abuse' 
   INJPCT  = 'Percentage of injection drug users' 
   TBPCT   = 'Percentage of clients w/ tuberculosis' 
   HIVPCT  = 'Percentage of clients with HIV' 
   PREVPCT = 'Percentage of clients who prev rcd tx' 
   MGDPCT  = 'Percent of clients covered by mgd care' 
   CTPCT   = 'Percent of court referred clients' 
   PREGPCT = 'Percentage of clients pregnant' 
   DEPPCT  = 'Percentage of women w/ dep children' 
   OPMLTOTL= 'Total Methadone/LAAM Outpatients' 
   HIMLTOTL= 'Total Methadone/LAAM Inpatients' 
   RCMLTOTL= 'Total Methadone/LAAM Residential' 
   MALE    = 'TOTAL OF MALES' 
   FEMALE  = 'TOTAL OF FEMALES' 
   UNKNOWN = 'TOTAL OF UNKNOWN SEX' 
   TTLGNDR = 'TOTAL OF BOTH SEXES' 
   WHITE   = 'TOTAL OF WHITES' 
   BLACK   = 'TOTAL OF BLACKS' 
   HISPANIC= 'TOTAL OF HISPANICS' 
   ASIAN   = 'TOTAL OF ASIANS' 
   AMERINDN= 'TOTAL OF AMER. INDIANS' 
   OTHER   = 'TOTAL OF OTHER RACES' 
   UNKRACE = 'TOTAL OF UNKNOWN RACE' 
   TTLRACE = 'TOTAL OF ALL RACES' 
   UNDER18 = 'TOTAL OF UNDER18' 
   X18_20  = 'TOTAL OF AGES 18-20' 
   X21_24  = 'TOTAL OF AGES 21-24' 
   X25_34  = 'TOTAL OF AGES 25-34' 
   X35_44  = 'TOTAL OF AGES 35-44' 
   X45_64  = 'TOTAL OF AGES 45-64' 
   OVER65  = 'TOTAL OF OVER 65' 
   UNKAGE  = 'TOTAL OF UNKNOWN AGES' 
   TTLAGE  = 'TOTAL OF ALL AGES' 
   H_SEX1FL= 'EDIT FLAG FOR H_SEX1' 
   H_SEX2FL= 'EDIT FLAG FOR H_SEX2' 
   H_SEX3FL= 'EDIT FLAG FOR H_SEX3' 
   H_SEX4FL= 'EDIT FLAG FOR H_SEX4' 
   H_RE1FL = 'EDIT FLAG FOR H_RE1' 
   H_RE2FL = 'EDIT FLAG FOR H_RE2' 
   H_RE3FL = 'EDIT FLAG FOR H_RE3' 
   H_RE4FL = 'EDIT FLAG FOR H_RE4' 
   H_RE5FL = 'EDIT FLAG FOR H_RE5' 
   H_RE6FL = 'EDIT FLAG FOR H_RE6' 
   H_RE7FL = 'EDIT FLAG FOR H_RE7' 
   H_RE8FL = 'EDIT FLAG FOR H_RE8' 
   H_AGE1FL= 'EDIT FLAG FOR H_AGE1' 
   H_AGE2FL= 'EDIT FLAG FOR H_AGE2' 
   H_AGE3FL= 'EDIT FLAG FOR H_AGE3' 
   H_AGE4FL= 'EDIT FLAG FOR H_AGE4' 
   H_AGE5FL= 'EDIT FLAG FOR H_AGE5' 
   H_AGE6FL= 'EDIT FLAG FOR H_AGE6' 
   H_AGE7FL= 'EDIT FLAG FOR H_AGE7' 
   H_AGE8FL= 'EDIT FLAG FOR H_AGE8' 
   H_AGE9FL= 'EDIT FLAG FOR H_AGE9' 
   O_SEX1FL= 'EDIT FLAG FOR O_SEX1' 
   O_SEX2FL= 'EDIT FLAG FOR O_SEX2' 
   O_SEX3FL= 'EDIT FLAG FOR O_SEX3' 
   O_SEX4FL= 'EDIT FLAG FOR O_SEX4' 
   O_RE1FL = 'EDIT FLAG FOR O_RE1' 
   O_RE2FL = 'EDIT FLAG FOR O_RE2' 
   O_RE3FL = 'EDIT FLAG FOR O_RE3' 
   O_RE4FL = 'EDIT FLAG FOR O_RE4' 
   O_RE5FL = 'EDIT FLAG FOR O_RE5' 
   O_RE6FL = 'EDIT FLAG FOR O_RE6' 
   O_RE7FL = 'EDIT FLAG FOR O_RE7' 
   O_RE8FL = 'EDIT FLAG FOR O_RE8' 
   O_AGE1FL= 'EDIT FLAG FOR O_AGE1' 
   O_AGE2FL= 'EDIT FLAG FOR O_AGE2' 
   O_AGE3FL= 'EDIT FLAG FOR O_AGE3' 
   O_AGE4FL= 'EDIT FLAG FOR O_AGE4' 
   O_AGE5FL= 'EDIT FLAG FOR O_AGE5' 
   O_AGE6FL= 'EDIT FLAG FOR O_AGE6' 
   O_AGE7FL= 'EDIT FLAG FOR O_AGE7' 
   O_AGE8FL= 'EDIT FLAG FOR O_AGE8' 
   O_AGE9FL= 'EDIT FLAG FOR O_AGE9' 
   R_SEX1FL= 'EDIT FLAG FOR R_SEX1' 
   R_SEX2FL= 'EDIT FLAG FOR R_SEX2' 
   R_SEX3FL= 'EDIT FLAG FOR R_SEX3' 
   R_SEX4FL= 'EDIT FLAG FOR R_SEX4' 
   R_RE1FL = 'EDIT FLAG FOR R_RE1' 
   R_RE2FL = 'EDIT FLAG FOR R_RE2' 
   R_RE3FL = 'EDIT FLAG FOR R_RE3' 
   R_RE4FL = 'EDIT FLAG FOR R_RE4' 
   R_RE5FL = 'EDIT FLAG FOR R_RE5' 
   R_RE6FL = 'EDIT FLAG FOR R_RE6' 
   R_RE7FL = 'EDIT FLAG FOR R_RE7' 
   R_RE8FL = 'EDIT FLAG FOR R_RE8' 
   R_AGE1FL= 'EDIT FLAG FOR R_AGE1' 
   R_AGE2FL= 'EDIT FLAG FOR R_AGE2' 
   R_AGE3FL= 'EDIT FLAG FOR R_AGE3' 
   R_AGE4FL= 'EDIT FLAG FOR R_AGE4' 
   R_AGE5FL= 'EDIT FLAG FOR R_AGE5' 
   R_AGE6FL= 'EDIT FLAG FOR R_AGE6' 
   R_AGE7FL= 'EDIT FLAG FOR R_AGE7' 
   R_AGE8FL= 'EDIT FLAG FOR R_AGE8' 
   R_AGE9FL= 'EDIT FLAG FOR R_AGE9' 
   TCLI1FL = 'EDIT FLAG FOR T_CLI1' 
   TCLI2FL = 'EDIT FLAG FOR T_CLI2' 
   TCLI3FL = 'EDIT FLAG FOR T_CLI3' 
   TCLI4FL = 'EDIT FLAG FOR T_CLI4' 
   TCLI5FL = 'EDIT FLAG FOR T_CLI5' 
   TCLI6FL = 'EDIT FLAG FOR T_CLI6' 
   TCLI7FL = 'EDIT FLAG FOR T_CLI7' 
   TCLIRCFL= 'EDIT FLAG FOR T_CLIRC' 
   TCLIOPFL= 'EDIT FLAG FOR T_CLIOP' 
   TCLIHIFL= 'EDIT FLAG FOR T_CLIHI' 
        ; 


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (MODE <= -1) THEN MODE = .;
   IF (STFIPS <= -1) THEN STFIPS = .;
   IF (TREATMT <= -1) THEN TREATMT = .;
   IF (DETOX <= -1) THEN DETOX = .;
   IF (PREVNTN <= -1) THEN PREVNTN = .;
   IF (OTHNONTX <= -1) THEN OTHNONTX = .;
   IF (OWNERSHP <= -1) THEN OWNERSHP = .;
   IF (FEDOWN <= -1) THEN FEDOWN = .;
   IF (LOC1 <= -1) THEN LOC1 = .;
   IF (LOC2 <= -1) THEN LOC2 = .;
   IF (LOC3 <= -1) THEN LOC3 = .;
   IF (LOC4 <= -1) THEN LOC4 = .;
   IF (LOC5 <= -1) THEN LOC5 = .;
   IF (LOC6 <= -1) THEN LOC6 = .;
   IF (LOC7 <= -1) THEN LOC7 = .;
   IF (LOC8 <= -1) THEN LOC8 = .;
   IF (LOC9 <= -1) THEN LOC9 = .;
   IF (LOC10 <= -1) THEN LOC10 = .;
   IF (LOC11 <= -1) THEN LOC11 = .;
   IF (LOC12 <= -1) THEN LOC12 = .;
   IF (LOC13 <= -1) THEN LOC13 = .;
   IF (LOC14 <= -1) THEN LOC14 = .;
   IF (LOC15 <= -1) THEN LOC15 = .;
   IF (LOC16 <= -1) THEN LOC16 = .;
   IF (MGMCARE <= -1) THEN MGMCARE = .;
   IF (WRITARRA <= -1) THEN WRITARRA = .;
   IF (WRITNUM <= -1) THEN WRITNUM = .;
   IF (OWNER <= -1) THEN OWNER = .;
   IF (SETTING <= -1) THEN SETTING = .;
   IF (ADMIN <= -1) THEN ADMIN = .;
   IF (SRVC1 <= -1) THEN SRVC1 = .;
   IF (SRVC2 <= -1) THEN SRVC2 = .;
   IF (SRVC3 <= -1) THEN SRVC3 = .;
   IF (SRVC4 <= -1) THEN SRVC4 = .;
   IF (SRVC5 <= -1) THEN SRVC5 = .;
   IF (SRVC6 <= -1) THEN SRVC6 = .;
   IF (SRVC7 <= -1) THEN SRVC7 = .;
   IF (SRVC8 <= -1) THEN SRVC8 = .;
   IF (SRVC9 <= -1) THEN SRVC9 = .;
   IF (SRVC10 <= -1) THEN SRVC10 = .;
   IF (SRVC11 <= -1) THEN SRVC11 = .;
   IF (SRVC12 <= -1) THEN SRVC12 = .;
   IF (SRVC13 <= -1) THEN SRVC13 = .;
   IF (SRVC14 <= -1) THEN SRVC14 = .;
   IF (SRVC15 <= -1) THEN SRVC15 = .;
   IF (SRVC16 <= -1) THEN SRVC16 = .;
   IF (SRVC17 <= -1) THEN SRVC17 = .;
   IF (SRVC18 <= -1) THEN SRVC18 = .;
   IF (SRVC19 <= -1) THEN SRVC19 = .;
   IF (SRVC20 <= -1) THEN SRVC20 = .;
   IF (SRVC21 <= -1) THEN SRVC21 = .;
   IF (SRVC22 <= -1) THEN SRVC22 = .;
   IF (SRVC23 <= -1) THEN SRVC23 = .;
   IF (SRVC24 <= -1) THEN SRVC24 = .;
   IF (SRVC25 <= -1) THEN SRVC25 = .;
   IF (SRVC26 <= -1) THEN SRVC26 = .;
   IF (SRVC27 <= -1) THEN SRVC27 = .;
   IF (SRVC28 <= -1) THEN SRVC28 = .;
   IF (SRVC29 <= -1) THEN SRVC29 = .;
   IF (SRVC36 <= -1) THEN SRVC36 = .;
   IF (SRVC37 <= -1) THEN SRVC37 = .;
   IF (SRVC38 <= -1) THEN SRVC38 = .;
   IF (SRVC39 <= -1) THEN SRVC39 = .;
   IF (SRVC40 <= -1) THEN SRVC40 = .;
   IF (SRVC41 <= -1) THEN SRVC41 = .;
   IF (SRVC42 <= -1) THEN SRVC42 = .;
   IF (SRVC43 <= -1) THEN SRVC43 = .;
   IF (SRVC44 <= -1) THEN SRVC44 = .;
   IF (SRVC45 <= -1) THEN SRVC45 = .;
   IF (SRVC46 <= -1) THEN SRVC46 = .;
   IF (SRVC47 <= -1) THEN SRVC47 = .;
   IF (SRVC48 <= -1) THEN SRVC48 = .;
   IF (SRVC49 <= -1) THEN SRVC49 = .;
   IF (SRVC50 <= -1) THEN SRVC50 = .;
   IF (SRVC51 <= -1) THEN SRVC51 = .;
   IF (SRVC52 <= -1) THEN SRVC52 = .;
   IF (SRVC53 <= -1) THEN SRVC53 = .;
   IF (SRVC54 <= -1) THEN SRVC54 = .;
   IF (SRVC55 <= -1) THEN SRVC55 = .;
   IF (SRVC56 <= -1) THEN SRVC56 = .;
   IF (SRVC57 <= -1) THEN SRVC57 = .;
   IF (SRVC58 <= -1) THEN SRVC58 = .;
   IF (SRVC59 <= -1) THEN SRVC59 = .;
   IF (SRVC60 <= -1) THEN SRVC60 = .;
   IF (SRVC30 <= -1) THEN SRVC30 = .;
   IF (SRVC31 <= -1) THEN SRVC31 = .;
   IF (SRVC32 <= -1) THEN SRVC32 = .;
   IF (SRVC33 <= -1) THEN SRVC33 = .;
   IF (SRVC34 <= -1) THEN SRVC34 = .;
   IF (SRVC35 <= -1) THEN SRVC35 = .;
   IF (TYPE1 <= -1) THEN TYPE1 = .;
   IF (TYPE2 <= -1) THEN TYPE2 = .;
   IF (TYPE3 <= -1) THEN TYPE3 = .;
   IF (TYPE4 <= -1) THEN TYPE4 = .;
   IF (TYPE5 <= -1) THEN TYPE5 = .;
   IF (TYPE6 <= -1) THEN TYPE6 = .;
   IF (TYPE7 <= -1) THEN TYPE7 = .;
   IF (ADMINLNK <= -1) THEN ADMINLNK = .;
   IF (FACNUM <= -1) THEN FACNUM = .;
   IF (OTHFAC1 <= -1) THEN OTHFAC1 = .;
   IF (OTHFAC2 <= -1) THEN OTHFAC2 = .;
   IF (OTHFAC3 <= -1) THEN OTHFAC3 = .;
   IF (CLIENTS4 <= -1) THEN CLIENTS4 = .;
   IF (HISVC <= -1) THEN HISVC = .;
   IF (HOSPBED <= -1) THEN HOSPBED = .;
   IF (T_CLI1 <= -1) THEN T_CLI1 = .;
   IF (T_CLI2 <= -1) THEN T_CLI2 = .;
   IF (T_CLIHI <= -1) THEN T_CLIHI = .;
   IF (HIMETLAM <= -1) THEN HIMETLAM = .;
   IF (HIMETNUM <= -1) THEN HIMETNUM = .;
   IF (HILAMNUM <= -1) THEN HILAMNUM = .;
   IF (H_SEX1 <= -1) THEN H_SEX1 = .;
   IF (H_SEX2 <= -1) THEN H_SEX2 = .;
   IF (H_SEX3 <= -1) THEN H_SEX3 = .;
   IF (H_SEX4 <= -1) THEN H_SEX4 = .;
   IF (H_RE1 <= -1) THEN H_RE1 = .;
   IF (H_RE2 <= -1) THEN H_RE2 = .;
   IF (H_RE3 <= -1) THEN H_RE3 = .;
   IF (H_RE4 <= -1) THEN H_RE4 = .;
   IF (H_RE5 <= -1) THEN H_RE5 = .;
   IF (H_RE6 <= -1) THEN H_RE6 = .;
   IF (H_RE7 <= -1) THEN H_RE7 = .;
   IF (H_RE8 <= -1) THEN H_RE8 = .;
   IF (H_AGE1 <= -1) THEN H_AGE1 = .;
   IF (H_AGE2 <= -1) THEN H_AGE2 = .;
   IF (H_AGE3 <= -1) THEN H_AGE3 = .;
   IF (H_AGE4 <= -1) THEN H_AGE4 = .;
   IF (H_AGE5 <= -1) THEN H_AGE5 = .;
   IF (H_AGE6 <= -1) THEN H_AGE6 = .;
   IF (H_AGE7 <= -1) THEN H_AGE7 = .;
   IF (H_AGE8 <= -1) THEN H_AGE8 = .;
   IF (H_AGE9 <= -1) THEN H_AGE9 = .;
   IF (RCSVC <= -1) THEN RCSVC = .;
   IF (RESBED <= -1) THEN RESBED = .;
   IF (T_CLI3 <= -1) THEN T_CLI3 = .;
   IF (T_CLI4 <= -1) THEN T_CLI4 = .;
   IF (T_CLIRC <= -1) THEN T_CLIRC = .;
   IF (RCMETLAM <= -1) THEN RCMETLAM = .;
   IF (RCMETNUM <= -1) THEN RCMETNUM = .;
   IF (RCLAMNUM <= -1) THEN RCLAMNUM = .;
   IF (R_SEX1 <= -1) THEN R_SEX1 = .;
   IF (R_SEX2 <= -1) THEN R_SEX2 = .;
   IF (R_SEX3 <= -1) THEN R_SEX3 = .;
   IF (R_SEX4 <= -1) THEN R_SEX4 = .;
   IF (R_RE1 <= -1) THEN R_RE1 = .;
   IF (R_RE2 <= -1) THEN R_RE2 = .;
   IF (R_RE3 <= -1) THEN R_RE3 = .;
   IF (R_RE4 <= -1) THEN R_RE4 = .;
   IF (R_RE5 <= -1) THEN R_RE5 = .;
   IF (R_RE6 <= -1) THEN R_RE6 = .;
   IF (R_RE7 <= -1) THEN R_RE7 = .;
   IF (R_RE8 <= -1) THEN R_RE8 = .;
   IF (R_AGE1 <= -1) THEN R_AGE1 = .;
   IF (R_AGE2 <= -1) THEN R_AGE2 = .;
   IF (R_AGE3 <= -1) THEN R_AGE3 = .;
   IF (R_AGE4 <= -1) THEN R_AGE4 = .;
   IF (R_AGE5 <= -1) THEN R_AGE5 = .;
   IF (R_AGE6 <= -1) THEN R_AGE6 = .;
   IF (R_AGE7 <= -1) THEN R_AGE7 = .;
   IF (R_AGE8 <= -1) THEN R_AGE8 = .;
   IF (R_AGE9 <= -1) THEN R_AGE9 = .;
   IF (OUTSVC <= -1) THEN OUTSVC = .;
   IF (T_CLI7 <= -1) THEN T_CLI7 = .;
   IF (T_CLI6 <= -1) THEN T_CLI6 = .;
   IF (T_CLI5 <= -1) THEN T_CLI5 = .;
   IF (T_CLIOP <= -1) THEN T_CLIOP = .;
   IF (OPMETLAM <= -1) THEN OPMETLAM = .;
   IF (OPMETNUM <= -1) THEN OPMETNUM = .;
   IF (OPLAMNUM <= -1) THEN OPLAMNUM = .;
   IF (O_SEX1 <= -1) THEN O_SEX1 = .;
   IF (O_SEX2 <= -1) THEN O_SEX2 = .;
   IF (O_SEX3 <= -1) THEN O_SEX3 = .;
   IF (O_SEX4 <= -1) THEN O_SEX4 = .;
   IF (O_RE1 <= -1) THEN O_RE1 = .;
   IF (O_RE2 <= -1) THEN O_RE2 = .;
   IF (O_RE3 <= -1) THEN O_RE3 = .;
   IF (O_RE4 <= -1) THEN O_RE4 = .;
   IF (O_RE5 <= -1) THEN O_RE5 = .;
   IF (O_RE6 <= -1) THEN O_RE6 = .;
   IF (O_RE7 <= -1) THEN O_RE7 = .;
   IF (O_RE8 <= -1) THEN O_RE8 = .;
   IF (O_AGE1 <= -1) THEN O_AGE1 = .;
   IF (O_AGE2 <= -1) THEN O_AGE2 = .;
   IF (O_AGE3 <= -1) THEN O_AGE3 = .;
   IF (O_AGE4 <= -1) THEN O_AGE4 = .;
   IF (O_AGE5 <= -1) THEN O_AGE5 = .;
   IF (O_AGE6 <= -1) THEN O_AGE6 = .;
   IF (O_AGE7 <= -1) THEN O_AGE7 = .;
   IF (O_AGE8 <= -1) THEN O_AGE8 = .;
   IF (O_AGE9 <= -1) THEN O_AGE9 = .;
   IF (TOTADMIS <= -1) THEN TOTADMIS = .;
   IF (SACL98 <= -1) THEN SACL98 = .;
   IF (B_PCT <= -1) THEN B_PCT = .;
   IF (A_PCT <= -1) THEN A_PCT = .;
   IF (D_PCT <= -1) THEN D_PCT = .;
   IF (INJPCT <= -1) THEN INJPCT = .;
   IF (TBPCT <= -1) THEN TBPCT = .;
   IF (HIVPCT <= -1) THEN HIVPCT = .;
   IF (PREVPCT <= -1) THEN PREVPCT = .;
   IF (MGDPCT <= -1) THEN MGDPCT = .;
   IF (CTPCT <= -1) THEN CTPCT = .;
   IF (PREGPCT <= -1) THEN PREGPCT = .;
   IF (DEPPCT <= -1) THEN DEPPCT = .;
   IF (OPMLTOTL <= -1) THEN OPMLTOTL = .;
   IF (HIMLTOTL <= -1) THEN HIMLTOTL = .;
   IF (RCMLTOTL <= -1) THEN RCMLTOTL = .;
   IF (MALE <= -1) THEN MALE = .;
   IF (FEMALE <= -1) THEN FEMALE = .;
   IF (UNKNOWN <= -1) THEN UNKNOWN = .;
   IF (TTLGNDR <= -1) THEN TTLGNDR = .;
   IF (WHITE <= -1) THEN WHITE = .;
   IF (BLACK <= -1) THEN BLACK = .;
   IF (HISPANIC <= -1) THEN HISPANIC = .;
   IF (ASIAN <= -1) THEN ASIAN = .;
   IF (AMERINDN <= -1) THEN AMERINDN = .;
   IF (OTHER <= -1) THEN OTHER = .;
   IF (UNKRACE <= -1) THEN UNKRACE = .;
   IF (TTLRACE <= -1) THEN TTLRACE = .;
   IF (UNDER18 <= -1) THEN UNDER18 = .;
   IF (X18_20 <= -1) THEN X18_20 = .;
   IF (X21_24 <= -1) THEN X21_24 = .;
   IF (X25_34 <= -1) THEN X25_34 = .;
   IF (X35_44 <= -1) THEN X35_44 = .;
   IF (X45_64 <= -1) THEN X45_64 = .;
   IF (OVER65 <= -1) THEN OVER65 = .;
   IF (UNKAGE <= -1) THEN UNKAGE = .;
   IF (TTLAGE <= -1) THEN TTLAGE = .;
   IF (H_SEX1FL <= -1) THEN H_SEX1FL = .;
   IF (H_SEX2FL <= -1) THEN H_SEX2FL = .;
   IF (H_SEX3FL <= -1) THEN H_SEX3FL = .;
   IF (H_SEX4FL <= -1) THEN H_SEX4FL = .;
   IF (H_RE1FL <= -1) THEN H_RE1FL = .;
   IF (H_RE2FL <= -1) THEN H_RE2FL = .;
   IF (H_RE3FL <= -1) THEN H_RE3FL = .;
   IF (H_RE4FL <= -1) THEN H_RE4FL = .;
   IF (H_RE5FL <= -1) THEN H_RE5FL = .;
   IF (H_RE6FL <= -1) THEN H_RE6FL = .;
   IF (H_RE7FL <= -1) THEN H_RE7FL = .;
   IF (H_RE8FL <= -1) THEN H_RE8FL = .;
   IF (H_AGE1FL <= -1) THEN H_AGE1FL = .;
   IF (H_AGE2FL <= -1) THEN H_AGE2FL = .;
   IF (H_AGE3FL <= -1) THEN H_AGE3FL = .;
   IF (H_AGE4FL <= -1) THEN H_AGE4FL = .;
   IF (H_AGE5FL <= -1) THEN H_AGE5FL = .;
   IF (H_AGE6FL <= -1) THEN H_AGE6FL = .;
   IF (H_AGE7FL <= -1) THEN H_AGE7FL = .;
   IF (H_AGE8FL <= -1) THEN H_AGE8FL = .;
   IF (H_AGE9FL <= -1) THEN H_AGE9FL = .;
   IF (O_SEX1FL <= -1) THEN O_SEX1FL = .;
   IF (O_SEX2FL <= -1) THEN O_SEX2FL = .;
   IF (O_SEX3FL <= -1) THEN O_SEX3FL = .;
   IF (O_SEX4FL <= -1) THEN O_SEX4FL = .;
   IF (O_RE1FL <= -1) THEN O_RE1FL = .;
   IF (O_RE2FL <= -1) THEN O_RE2FL = .;
   IF (O_RE3FL <= -1) THEN O_RE3FL = .;
   IF (O_RE4FL <= -1) THEN O_RE4FL = .;
   IF (O_RE5FL <= -1) THEN O_RE5FL = .;
   IF (O_RE6FL <= -1) THEN O_RE6FL = .;
   IF (O_RE7FL <= -1) THEN O_RE7FL = .;
   IF (O_RE8FL <= -1) THEN O_RE8FL = .;
   IF (O_AGE1FL <= -1) THEN O_AGE1FL = .;
   IF (O_AGE2FL <= -1) THEN O_AGE2FL = .;
   IF (O_AGE3FL <= -1) THEN O_AGE3FL = .;
   IF (O_AGE4FL <= -1) THEN O_AGE4FL = .;
   IF (O_AGE5FL <= -1) THEN O_AGE5FL = .;
   IF (O_AGE6FL <= -1) THEN O_AGE6FL = .;
   IF (O_AGE7FL <= -1) THEN O_AGE7FL = .;
   IF (O_AGE8FL <= -1) THEN O_AGE8FL = .;
   IF (O_AGE9FL <= -1) THEN O_AGE9FL = .;
   IF (R_SEX1FL <= -1) THEN R_SEX1FL = .;
   IF (R_SEX2FL <= -1) THEN R_SEX2FL = .;
   IF (R_SEX3FL <= -1) THEN R_SEX3FL = .;
   IF (R_SEX4FL <= -1) THEN R_SEX4FL = .;
   IF (R_RE1FL <= -1) THEN R_RE1FL = .;
   IF (R_RE2FL <= -1) THEN R_RE2FL = .;
   IF (R_RE3FL <= -1) THEN R_RE3FL = .;
   IF (R_RE4FL <= -1) THEN R_RE4FL = .;
   IF (R_RE5FL <= -1) THEN R_RE5FL = .;
   IF (R_RE6FL <= -1) THEN R_RE6FL = .;
   IF (R_RE7FL <= -1) THEN R_RE7FL = .;
   IF (R_RE8FL <= -1) THEN R_RE8FL = .;
   IF (R_AGE1FL <= -1) THEN R_AGE1FL = .;
   IF (R_AGE2FL <= -1) THEN R_AGE2FL = .;
   IF (R_AGE3FL <= -1) THEN R_AGE3FL = .;
   IF (R_AGE4FL <= -1) THEN R_AGE4FL = .;
   IF (R_AGE5FL <= -1) THEN R_AGE5FL = .;
   IF (R_AGE6FL <= -1) THEN R_AGE6FL = .;
   IF (R_AGE7FL <= -1) THEN R_AGE7FL = .;
   IF (R_AGE8FL <= -1) THEN R_AGE8FL = .;
   IF (R_AGE9FL <= -1) THEN R_AGE9FL = .;
   IF (TCLI1FL <= -1) THEN TCLI1FL = .;
   IF (TCLI2FL <= -1) THEN TCLI2FL = .;
   IF (TCLI3FL <= -1) THEN TCLI3FL = .;
   IF (TCLI4FL <= -1) THEN TCLI4FL = .;
   IF (TCLI5FL <= -1) THEN TCLI5FL = .;
   IF (TCLI6FL <= -1) THEN TCLI6FL = .;
   IF (TCLI7FL <= -1) THEN TCLI7FL = .;
   IF (TCLIRCFL <= -1) THEN TCLIRCFL = .;
   IF (TCLIOPFL <= -1) THEN TCLIOPFL = .;
   IF (TCLIHIFL <= -1) THEN TCLIHIFL = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT MODE mode. STFIPS stfips. TREATMT treatmt.
         DETOX detox. PREVNTN prevntn. OTHNONTX othnontx.
         OWNERSHP ownershp. FEDOWN fedown. LOC1 loc1ffff.
         LOC2 loc2ffff. LOC3 loc3ffff. LOC4 loc4ffff.
         LOC5 loc5ffff. LOC6 loc6ffff. LOC7 loc7ffff.
         LOC8 loc8ffff. LOC9 loc9ffff. LOC10 loc10fff.
         LOC11 loc11fff. LOC12 loc12fff. LOC13 loc13fff.
         LOC14 loc14fff. LOC15 loc15fff. LOC16 loc16fff.
         MGMCARE mgmcare. WRITARRA writarra. WRITNUM writnum.
         OWNER owner. SETTING setting. ADMIN admin.
         SRVC1 srvc1fff. SRVC2 srvc2fff. SRVC3 srvc3fff.
         SRVC4 srvc4fff. SRVC5 srvc5fff. SRVC6 srvc6fff.
         SRVC7 srvc7fff. SRVC8 srvc8fff. SRVC9 srvc9fff.
         SRVC10 srvc10ff. SRVC11 srvc11ff. SRVC12 srvc12ff.
         SRVC13 srvc13ff. SRVC14 srvc14ff. SRVC15 srvc15ff.
         SRVC16 srvc16ff. SRVC17 srvc17ff. SRVC18 srvc18ff.
         SRVC19 srvc19ff. SRVC20 srvc20ff. SRVC21 srvc21ff.
         SRVC22 srvc22ff. SRVC23 srvc23ff. SRVC24 srvc24ff.
         SRVC25 srvc25ff. SRVC26 srvc26ff. SRVC27 srvc27ff.
         SRVC28 srvc28ff. SRVC29 srvc29ff. SRVC36 srvc36ff.
         SRVC37 srvc37ff. SRVC38 srvc38ff. SRVC39 srvc39ff.
         SRVC40 srvc40ff. SRVC41 srvc41ff. SRVC42 srvc42ff.
         SRVC43 srvc43ff. SRVC44 srvc44ff. SRVC45 srvc45ff.
         SRVC46 srvc46ff. SRVC47 srvc47ff. SRVC48 srvc48ff.
         SRVC49 srvc49ff. SRVC50 srvc50ff. SRVC51 srvc51ff.
         SRVC52 srvc52ff. SRVC53 srvc53ff. SRVC54 srvc54ff.
         SRVC55 srvc55ff. SRVC56 srvc56ff. SRVC57 srvc57ff.
         SRVC58 srvc58ff. SRVC59 srvc59ff. SRVC60 srvc60ff.
         SRVC30 srvc30ff. SRVC31 srvc31ff. SRVC32 srvc32ff.
         SRVC33 srvc33ff. SRVC34 srvc34ff. SRVC35 srvc35ff.
         TYPE1 type1fff. TYPE2 type2fff. TYPE3 type3fff.
         TYPE4 type4fff. TYPE5 type5fff. TYPE6 type6fff.
         TYPE7 type7fff. ADMINLNK adminlnk. FACNUM facnum.
         OTHFAC1 othfac1f. OTHFAC2 othfac2f. OTHFAC3 othfac3f.
         CLIENTS4 clientsf. HISVC hisvc. HOSPBED hospbed.
         T_CLI1 t_cli1ff. T_CLI2 t_cli2ff. T_CLIHI t_clihi.
         HIMETLAM himetlam. HIMETNUM himetnum. HILAMNUM hilamnum.
         H_SEX1 h_sex1ff. H_SEX2 h_sex2ff. H_SEX3 h_sex3ff.
         H_SEX4 h_sex4ff. H_RE1 h_re1fff. H_RE2 h_re2fff.
         H_RE3 h_re3fff. H_RE4 h_re4fff. H_RE5 h_re5fff.
         H_RE6 h_re6fff. H_RE7 h_re7fff. H_RE8 h_re8fff.
         H_AGE1 h_age1ff. H_AGE2 h_age2ff. H_AGE3 h_age3ff.
         H_AGE4 h_age4ff. H_AGE5 h_age5ff. H_AGE6 h_age6ff.
         H_AGE7 h_age7ff. H_AGE8 h_age8ff. H_AGE9 h_age9ff.
         RCSVC rcsvc. RESBED resbed. T_CLI3 t_cli3ff.
         T_CLI4 t_cli4ff. T_CLIRC t_clirc. RCMETLAM rcmetlam.
         RCMETNUM rcmetnum. RCLAMNUM rclamnum. R_SEX1 r_sex1ff.
         R_SEX2 r_sex2ff. R_SEX3 r_sex3ff. R_SEX4 r_sex4ff.
         R_RE1 r_re1fff. R_RE2 r_re2fff. R_RE3 r_re3fff.
         R_RE4 r_re4fff. R_RE5 r_re5fff. R_RE6 r_re6fff.
         R_RE7 r_re7fff. R_RE8 r_re8fff. R_AGE1 r_age1ff.
         R_AGE2 r_age2ff. R_AGE3 r_age3ff. R_AGE4 r_age4ff.
         R_AGE5 r_age5ff. R_AGE6 r_age6ff. R_AGE7 r_age7ff.
         R_AGE8 r_age8ff. R_AGE9 r_age9ff. OUTSVC outsvc.
         T_CLI7 t_cli7ff. T_CLI6 t_cli6ff. T_CLI5 t_cli5ff.
         T_CLIOP t_cliop. OPMETLAM opmetlam. OPMETNUM opmetnum.
         OPLAMNUM oplamnum. O_SEX1 o_sex1ff. O_SEX2 o_sex2ff.
         O_SEX3 o_sex3ff. O_SEX4 o_sex4ff. O_RE1 o_re1fff.
         O_RE2 o_re2fff. O_RE3 o_re3fff. O_RE4 o_re4fff.
         O_RE5 o_re5fff. O_RE6 o_re6fff. O_RE7 o_re7fff.
         O_RE8 o_re8fff. O_AGE1 o_age1ff. O_AGE2 o_age2ff.
         O_AGE3 o_age3ff. O_AGE4 o_age4ff. O_AGE5 o_age5ff.
         O_AGE6 o_age6ff. O_AGE7 o_age7ff. O_AGE8 o_age8ff.
         O_AGE9 o_age9ff. TOTADMIS totadmis. SACL98 sacl98ff.
         B_PCT b_pct. A_PCT a_pct. D_PCT d_pct.
         INJPCT injpct. TBPCT tbpct. HIVPCT hivpct.
         PREVPCT prevpct. MGDPCT mgdpct. CTPCT ctpct.
         PREGPCT pregpct. DEPPCT deppct. OPMLTOTL opmltotl.
         HIMLTOTL himltotl. RCMLTOTL rcmltotl. MALE male.
         FEMALE female. UNKNOWN unknown. TTLGNDR ttlgndr.
         WHITE white. BLACK black. HISPANIC hispanic.
         ASIAN asian. AMERINDN amerindn. OTHER other.
         UNKRACE unkrace. TTLRACE ttlrace. UNDER18 under18f.
         X18_20 x18_20ff. X21_24 x21_24ff. X25_34 x25_34ff.
         X35_44 x35_44ff. X45_64 x45_64ff. OVER65 over65ff.
         UNKAGE unkage. TTLAGE ttlage. H_SEX1FL h_sex1fl.
         H_SEX2FL h_sex2fl. H_SEX3FL h_sex3fl. H_SEX4FL h_sex4fl.
         H_RE1FL h_re1fl. H_RE2FL h_re2fl. H_RE3FL h_re3fl.
         H_RE4FL h_re4fl. H_RE5FL h_re5fl. H_RE6FL h_re6fl.
         H_RE7FL h_re7fl. H_RE8FL h_re8fl. H_AGE1FL h_age1fl.
         H_AGE2FL h_age2fl. H_AGE3FL h_age3fl. H_AGE4FL h_age4fl.
         H_AGE5FL h_age5fl. H_AGE6FL h_age6fl. H_AGE7FL h_age7fl.
         H_AGE8FL h_age8fl. H_AGE9FL h_age9fl. O_SEX1FL o_sex1fl.
         O_SEX2FL o_sex2fl. O_SEX3FL o_sex3fl. O_SEX4FL o_sex4fl.
         O_RE1FL o_re1fl. O_RE2FL o_re2fl. O_RE3FL o_re3fl.
         O_RE4FL o_re4fl. O_RE5FL o_re5fl. O_RE6FL o_re6fl.
         O_RE7FL o_re7fl. O_RE8FL o_re8fl. O_AGE1FL o_age1fl.
         O_AGE2FL o_age2fl. O_AGE3FL o_age3fl. O_AGE4FL o_age4fl.
         O_AGE5FL o_age5fl. O_AGE6FL o_age6fl. O_AGE7FL o_age7fl.
         O_AGE8FL o_age8fl. O_AGE9FL o_age9fl. R_SEX1FL r_sex1fl.
         R_SEX2FL r_sex2fl. R_SEX3FL r_sex3fl. R_SEX4FL r_sex4fl.
         R_RE1FL r_re1fl. R_RE2FL r_re2fl. R_RE3FL r_re3fl.
         R_RE4FL r_re4fl. R_RE5FL r_re5fl. R_RE6FL r_re6fl.
         R_RE7FL r_re7fl. R_RE8FL r_re8fl. R_AGE1FL r_age1fl.
         R_AGE2FL r_age2fl. R_AGE3FL r_age3fl. R_AGE4FL r_age4fl.
         R_AGE5FL r_age5fl. R_AGE6FL r_age6fl. R_AGE7FL r_age7fl.
         R_AGE8FL r_age8fl. R_AGE9FL r_age9fl. TCLI1FL tcli1fl.
         TCLI2FL tcli2fl. TCLI3FL tcli3fl. TCLI4FL tcli4fl.
         TCLI5FL tcli5fl. TCLI6FL tcli6fl. TCLI7FL tcli7fl.
         TCLIRCFL tclircfl. TCLIOPFL tcliopfl. TCLIHIFL tclihifl.
          ;
*/

RUN ;
